export declare enum BlockType {
    Word = "Word",
    Checkbox = "Checkbox"
}
export declare enum FieldType {
    Text = "Text",
    Checkbox = "Checkbox",
    Signature = "Signature",
    Table = "Table"
}
export declare enum Confidence {
    High = "High",
    Low = "Low",
    UserReviewed = "UserReviewed"
}
export declare enum MimeType {
    Pdf = "application/pdf",
    Png = "image/png",
    Jpg = "image/jpeg"
}
export declare type BoundingBoxDto = {
    /**
     * Relative width of this bounding box to page width
     * @type {number}
     * @memberof BoundingBoxDto
     */
    width: number;
    /**
    * Relative height of this bounding box to page height
    * @type {number}
    * @memberof BoundingBoxDto
    */
    height: number;
    /**
    * Relative position of leftmost point of this bounding box on the page
    * @type {number}
    * @memberof BoundingBoxDto
    */
    left: number;
    /**
    * Relative position of uppermost point of this bounding box on the page
    * @type {number}
    * @memberof BoundingBoxDto
    */
    top: number;
    /**
    * Page number
    * @type {number}
    * @memberof BoundingBoxDto
    */
    page: number;
};
export declare type BlockDto = {
    /**
     * Unique identifier of the block
     * @type {string}
     * @memberof BlockDto
     */
    id: string;
    /**
     * Type of Block that was extracted
     * @type {BlockType}
     * @memberof BlockDto
     */
    blockType: BlockType;
    /**
     * Text contained within the block that was extracted
     * @type {string}
     * @memberof BlockDto
     */
    text: string;
    /**
     * Coordinates of the bounding box containing the extracted block
     * @type {BoundingBoxDto}
     * @memberof BlockDto
     */
    boundingBox: BoundingBoxDto;
};
export declare type FieldLabelDto = {
    /**
     * Unique identifier of the field label
     * @type {string}
     * @memberof FieldLabelDto
     */
    id: string;
    /**
     * Name of the field that the label corresponds to
     * @type {string}
     * @memberof FieldLabelDto
     */
    name: string;
    /**
     * The type of field that the label corresponds to
     * @type {FieldType}
     * @memberof FieldLabelDto
     */
    type: FieldType;
    /**
     * Extraction Confidence Score for the field label
     * @type {Confidence}
     * @memberof FieldLabelDto
     */
    confidenceScore: Confidence;
    /**
     * Blocks that have been labeled for this field
     * @type {[BlockDto]}
     * @memberof FieldLabelDto
     */
    blocks: Array<BlockDto>;
    /**
     * Region that has been labeled for this field
     * @type {BoundingBoxDto}
     * @memberof FieldLabelDto
     */
    region?: BoundingBoxDto;
    /**
     * Manual text override that was inputted by a user
     * @type {string}
     * @memberof FieldLabelDto
     */
    textOverride?: string;
};
export declare type CellLabelDto = {
    /**
     * Unique identifier of the column that this cell label belongs to
     * @type {string}
     * @memberof CellLabelDto
     */
    columnId: string;
    /**
    * Extraction Confidence Score for the cell label
    * @type {Confidence}
    * @memberof CellLabelDto
    */
    confidenceScore: Confidence;
    /**
    * Blocks that have been labeled for this cell
    * @type {[BlockDto]}
    * @memberof CellLabelDto
    */
    blocks: Array<BlockDto>;
    /**
    * Region that has been labeled for this cell
    * @type {BoundingBoxDto}
    * @memberof CellLabelDto
    */
    region?: BoundingBoxDto;
    /**
    * Manual text override that was inputted by a user
    * @type {string}
    * @memberof CellLabelDto
    */
    textOverride?: string;
};
export declare type RowLabelDto = {
    /**
     * Unique identifier of the row label
     * @type {string}
     * @memberof RowLabelDto
     */
    id: string;
    /**
     * Cell labels contained within this row
     * @type {[CellLabelDto]}
     * @memberof RowLabelDto
     */
    cells: Array<CellLabelDto>;
};
export declare type ColumnDto = {
    /**
     * Unique identifier of the column
     * @type {string}
     * @memberof ColumnDto
     */
    id: string;
    /**
    * Name of the column within the table
    * @type {string}
    * @memberof ColumnDto
    */
    name: string;
};
export declare type TableLabelDto = {
    /**
     * Unique identifier of the table label
     * @type {string}
     * @memberof TableLabelDto
     */
    id: string;
    /**
    * Name of the table that the label corresponds to
    * @type {string}
    * @memberof TableLabelDto
    */
    name: string;
    /**
    * Extraction Confidence Score for the table label
    * @type {Confidence}
    * @memberof TableLabelDto
    */
    confidenceScore: Confidence;
    /**
    * Column names for this table label
    * @type {[ColumnDto]}
    * @memberof TableLabelDto
    */
    columns: Array<ColumnDto>;
    /**
    * Array of row labels for this table label
    * @type {[RowLabelDto]}
    * @memberof TableLabelDto
    */
    rows: Array<RowLabelDto>;
};
export declare type LabelDto = {
    /**
    * Array of field labels for this document label
    * @type {[FieldLabelDto]}
    * @memberof LabelDto
    */
    fields: Array<FieldLabelDto>;
    /**
     * Array of table labels for this document label
     * @type {[TableLabelDto]}
     * @memberof LabelDto
     */
    tables: Array<TableLabelDto>;
};
declare type SharedLabelOutputDto = {
    id: string;
    name: string;
    confidenceScore: Confidence;
    type: FieldType;
};
export declare type FieldLabelOutputDto = SharedLabelOutputDto & {
    blocks: Array<BlockDto>;
    region?: BoundingBoxDto;
};
export declare type SignatureLabelOutputDto = SharedLabelOutputDto & {
    region?: BoundingBoxDto;
};
export declare type CellLabelOutputDto = {
    columnId: string;
    confidenceScore: Confidence;
    blocks: Array<BlockDto>;
    region?: BoundingBoxDto;
};
export declare type RowLabelOutputDto = {
    id: string;
    cells: Array<CellLabelOutputDto>;
};
export declare type TableLabelOutputDto = SharedLabelOutputDto & {
    columns: Array<ColumnDto>;
    rows: Array<RowLabelOutputDto>;
};
export declare type TrainingDocumentResultDto = {
    fields: Array<FieldLabelOutputDto>;
    signatures: Array<SignatureLabelOutputDto>;
    tables: Array<TableLabelOutputDto>;
};
export declare type TrainingDocumentLabelsDto = {
    modelId: string;
    docId: string;
    results: TrainingDocumentResultDto;
};
export declare type ExtractedFieldDto = {
    fieldName: string;
    value: string;
    confidenceScore: Confidence;
};
export declare type ExtractedTableCellDto = {
    columnName: string;
    value: string;
    confidenceScore: Confidence;
};
export declare type ExtractedTableRowDto = {
    cells: Array<ExtractedTableCellDto>;
};
export declare type ExtractedTableDto = {
    tableName: string;
    rows: Array<ExtractedTableRowDto>;
    confidenceScore: Confidence;
};
export declare type ExtractionResultDto = {
    documentId: string;
    documentStatus: 'Completed';
    fileName: string;
    mimeType: MimeType;
    confidenceScore: Confidence;
    formFields: Array<ExtractedFieldDto>;
    tables: Array<ExtractedTableDto>;
};
export declare type DocumentLabelerOutputDataDto = {
    extractionResult: ExtractionResultDto;
    trainingDocumentLabels: TrainingDocumentLabelsDto;
};
export {};
