import { ColorUtils } from "documentLabeler/color/ColorUtils";
import { BlockUtils } from "documentLabeler/components/documentPanel/documentBlockLayer/utils/BlockUtils";
import { MockDocumentLabelerData } from "documentLabeler/MockDocumentLabelerData.stories";
import { LabelingSelectionType } from "documentLabeler/state/DocumentLabelerState";
import { BlockType, FieldType } from "common/types/DocumentLabelerTypes";
var mockPageHeights = [500, 400, 500, 300];
var mockWidth = 400;
var simpleRectangle = {
    start: {
        x: 100,
        y: 200,
    },
    end: {
        x: 300,
        y: 300,
    },
};
var simpleBoundingBox = {
    top: 0.4,
    left: 0.25,
    width: 0.5,
    height: 0.2,
    page: 0,
};
var page1Rectangle = {
    start: {
        x: 100,
        y: 700,
    },
    end: {
        x: 200,
        y: 900,
    },
};
var page1BoundingBox = {
    top: 0.5,
    left: 0.25,
    width: 0.25,
    height: 0.5,
    page: 1,
};
var backwardsRectangle = {
    start: {
        x: 300,
        y: 400,
    },
    end: {
        x: 100,
        y: 300,
    },
};
var backwardsBoundingBox = {
    top: 0.6,
    left: 0.25,
    width: 0.5,
    height: 0.2,
    page: 0,
};
var simpleBlock = {
    id: 'block1',
    blockType: BlockType.Word,
    text: 'test',
    boundingBox: simpleBoundingBox,
    confidence: 1,
};
var fieldColoredBlock = {
    block: simpleBlock,
    color: ColorUtils.getColorFromColorSet(0),
    sourceFieldId: 'field1',
    sourceFieldType: FieldType.Text,
};
var cellColoredBlock = {
    block: simpleBlock,
    color: ColorUtils.getColorFromColorSet(0),
    columnId: 'col1',
    rowId: 'row1',
    tableId: 'table1',
    sourceFieldType: FieldType.Table,
};
describe('getRegionFromRectangle', function () {
    it('should correctly convert simple rectangles', function () {
        var convertedBbx = BlockUtils.getRegionFromRectangle(simpleRectangle, mockWidth, mockPageHeights);
        expect(convertedBbx).toMatchObject(simpleBoundingBox);
    });
    it('should correctly convert rectangles on not the first page', function () {
        var convertedBbx = BlockUtils.getRegionFromRectangle(page1Rectangle, mockWidth, mockPageHeights);
        expect(convertedBbx).toMatchObject(page1BoundingBox);
    });
    it('should correctly convert simple rectangles', function () {
        var convertedBbx = BlockUtils.getRegionFromRectangle(backwardsRectangle, mockWidth, mockPageHeights);
        expect(convertedBbx).toMatchObject(backwardsBoundingBox);
    });
});
describe('getFilteredUnhighlightedBlocks', function () {
    var wordBlocks = MockDocumentLabelerData.wordBlocks;
    it('should display all word blocks with no selectedField', function () {
        var displayBlocks = BlockUtils.getFilteredUnhighlightedBlocks(undefined, [], wordBlocks, LabelingSelectionType.Block);
        expect(displayBlocks).toMatchObject(wordBlocks);
    });
    it('should display no word blocks when selection type is region', function () {
        var displayBlocks = BlockUtils.getFilteredUnhighlightedBlocks(undefined, [], wordBlocks, LabelingSelectionType.Region);
        expect(displayBlocks).toMatchObject([]);
    });
    it('should display no blocks with a signature field selected', function () {
        var selectedSignatureField = {
            id: 'signatureId',
            type: FieldType.Signature,
        };
        var displayBlocks = BlockUtils.getFilteredUnhighlightedBlocks(selectedSignatureField, [], wordBlocks, LabelingSelectionType.Region);
        expect(displayBlocks).toMatchObject([]);
    });
    it('should display only word blocks with a text field selected', function () {
        var selectedTextField = {
            id: 'textId',
            type: FieldType.Text,
        };
        var displayBlocks = BlockUtils.getFilteredUnhighlightedBlocks(selectedTextField, [], wordBlocks, LabelingSelectionType.Block);
        var expectedBlocks = wordBlocks.filter(function (block) { return block.blockType === BlockType.Word; });
        expect(displayBlocks).toMatchObject(expectedBlocks);
    });
    it('should display only checkbox blocks with a checkbox field selected', function () {
        var selectedCheckboxField = {
            id: 'checkboxId',
            type: FieldType.Checkbox,
        };
        var displayBlocks = BlockUtils.getFilteredUnhighlightedBlocks(selectedCheckboxField, [], wordBlocks, LabelingSelectionType.Block);
        var expectedBlocks = wordBlocks.filter(function (block) { return block.blockType === BlockType.Checkbox; });
        expect(displayBlocks).toMatchObject(expectedBlocks);
    });
    it('should filter out blocks from an active text field', function () {
        var selectedTextField = {
            id: 'textId',
            type: FieldType.Text,
        };
        // Define first two word blocks to be associated with selected text field
        var coloredBlocks = wordBlocks
            .filter(function (block) { return block.blockType === BlockType.Word; })
            .slice(0, 2)
            .map(function (block) { return ({
            color: 'color',
            block: block,
            sourceFieldId: 'textId',
            sourceFieldType: FieldType.Text,
        }); });
        var displayBlocks = BlockUtils.getFilteredUnhighlightedBlocks(selectedTextField, coloredBlocks, wordBlocks, LabelingSelectionType.Block);
        // expect display blocks to filter out first two blocks
        var expectedBlocks = wordBlocks
            .slice(2)
            .filter(function (block) { return block.blockType !== BlockType.Checkbox; });
        expect(displayBlocks).toMatchObject(expectedBlocks);
    });
    it('should filter out blocks from an active table field', function () {
        var selectedTableField = {
            id: 'tableId',
            type: FieldType.Table,
            activeCell: {
                rowId: 'rowId',
                columnId: 'columnId',
            },
        };
        var coloredBlocks = [
            MockDocumentLabelerData.wordBlocks[4],
        ].map(function (block) { return ({
            color: 'cell',
            block: block,
            tableId: 'tableId',
            rowId: 'rowId',
            columnId: 'columnId',
            sourceFieldType: FieldType.Table,
        }); });
        var displayBlocks = BlockUtils.getFilteredUnhighlightedBlocks(selectedTableField, coloredBlocks, wordBlocks, LabelingSelectionType.Block);
        var expectedBlocks = wordBlocks
            .filter(function (block) { return block.id !== MockDocumentLabelerData.wordBlocks[4].id; })
            .filter(function (block) { return block.blockType !== BlockType.Checkbox; });
        expect(displayBlocks).toMatchObject(expectedBlocks);
    });
});
describe('getColoredBlockOpacity', function () {
    it('should return opacity 1 for field block', function () {
        var opacity = BlockUtils.getColoredBlockOpacity(fieldColoredBlock);
        expect(opacity).toBe(1);
    });
    it('should return opacity 1 for cell block if theres no active cell', function () {
        var opacity = BlockUtils.getColoredBlockOpacity(cellColoredBlock);
        expect(opacity).toBe(1);
    });
    it("should return opacity 1 for cell block if it's active cell's block", function () {
        var selectedTableField = {
            id: 'tableId',
            type: FieldType.Table,
            activeCell: {
                rowId: 'rowId',
                columnId: 'columnId',
            },
        };
        var opacity1 = BlockUtils.getColoredBlockOpacity(cellColoredBlock, selectedTableField);
        expect(opacity1).toBe(1);
        // Check for blocks not associated with the activeCell
        selectedTableField.id = 'table2';
        var opacity2 = BlockUtils.getColoredBlockOpacity(cellColoredBlock, selectedTableField);
        expect(opacity2).toBe(0.3);
    });
});
describe('sortBlocks', function () {
    it('should sort the blocks in correct order', function () {
        var blocks = MockDocumentLabelerData.wordBlocks;
        var SORTED_BLOCK_RESULT = [
            blocks[0],
            blocks[1],
            blocks[5],
            blocks[4],
            blocks[2],
            blocks[3],
        ];
        var sortedBlocks = BlockUtils.sortBlocks(blocks);
        expect(sortedBlocks).toStrictEqual(SORTED_BLOCK_RESULT);
    });
});
